@@ -11,6 +11,7 @@ from googleapiclient.errors import HttpError
 from ratelimit import limits, sleep_and_retry
 
 from ytscraper.helper.echo import echow, echoe
+import re
 
 
 def related_search(handle, number, videoId, **api_options):
@@ -30,9 +31,9 @@ def _search(handle, number, **api_options):
     api_options["part"] = "id,snippet"
     response = _get_response(handle.search(), **api_options)
     video_data = [_extract_data(video) for video in response["items"]]
-    if len(video_data) != number:
+    if len(video_data) < number:
         echow(
-            f"API gave different number of videos than requested: {len(video_data)} instead of {number}!"
+            f"API gave less number of videos than requested: {len(video_data)} instead of {number}!"
         )
     return video_data[:number]
 
@@ -63,10 +64,10 @@ def _extract_data(item):
         except TypeError:
             result["videoId"] = item["id"]
     if "snippet" in item:
-        result["title"] = item["snippet"]["title"]
-        # result["description"] = item["snippet"]["description"]
-        result["publishedAt"] = item["snippet"]["publishedAt"]
         result["channdelId"] = item["snippet"]["channelId"]
+        result["title"] = item["snippet"]["title"]
+        result["description"] = item["snippet"]["description"]
+        result["publishedAt"] = item["snippet"]["publishedAt"]
         result["channelTitle"] = item["snippet"]["channelTitle"]
     return result
 
